[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Module Hierarchy

- doapfiend: http://trac.doapspace.org/doapfiend
  - doapfiend.cli: Command-line tool for querying, serializing and displaying DOAP
  - doapfiend.doaplib: Library for parsing, displaying, querying and serializing DOAP
  - doapfiend.lexers: Lexers for semantic web languages.
  - doapfiend.model: Model of a DOAP profile using RDFAlchemy
  - doapfiend.plugins: doapfiend supports setuptools_ entry point plugins.
    - doapfiend.plugins.base: All plugins should inherit doapfiend.plugins.Plugin
    - doapfiend.plugins.freshmeat: Currently this plugin uses http://doapspace.org/ to fetch DOAP for Freshmeat
    - doapfiend.plugins.homepage: Fetches DOAP by searching doapspace.org by a project's homepage.
    - doapfiend.plugins.n3: This is a plugin for formatting DOAP output as N3 (Notation 3) syntax.
    - doapfiend.plugins.pkg_index: Plugin helper to fetch a single DOAP file from doapspace.org by Package Index
    - doapfiend.plugins.pypi: Currently this plugin uses http://doapspace.org/ to fetch DOAP for PyPI (The Python Package Index)
    - doapfiend.plugins.sourceforge: Currently this plugin uses http://doapspace.org/ to fetch DOAP for SourceForge
    - doapfiend.plugins.text: This plugin outputs DOAP in human-readable plain text
    - doapfiend.plugins.url: This plugin loads DOAP by its URL or path to a filename.
    - doapfiend.plugins.xml: This plugin outputs DOAP in RDF/XML It basically does nothing because all DOAP today is in RDF/XML.
  - doapfiend.utils: General purpose helper functions and classes for doapfiend You'll probably want to use doaplib for most cases.